@@ -55,6 +55,10 @@ class Model(object):
     [1, 2]
     >>> t.item = 2
     >>> t.item1 = 'val2'
+    >>> t.item1 = 'val0'
+    Traceback (most recent call last):
+        ...
+    KeyError: 'val0'
     
     >>> t.hash['a'] = 'b'
     >>> t.save()
